@@ -8,6 +8,10 @@ test_that("get_phylopic works", {
   expect_true(is(get_phylopic(uuid = uuid, format = "raster"), "array"))
   expect_true(is(get_phylopic(uuid = uuid, format = "raster",
                               height = 300), "array"))
+  expect_true(is(get_phylopic(uuid = uuid, format = "vector", source = TRUE),
+                 "Picture"))
+  expect_true(is(get_phylopic(uuid = uuid, format = "raster", source = TRUE),
+                 "array"))
 
   expect_no_error(get_phylopic(uuid = uuid, preview = TRUE))
 
@@ -18,6 +22,6 @@ test_that("get_phylopic works", {
   expect_error(get_phylopic(uuid = uuid, format = "VHS"))
   expect_error(get_phylopic(uuid = uuid, preview = "yes"))
   # 512 was deprecated for format
-  expect_warning(get_phylopic(uuid = "c8f71c27-71db-4b34-ac2d-e97fea8762cf",
-                              format = "512"))
+  expect_error(get_phylopic(uuid = "c8f71c27-71db-4b34-ac2d-e97fea8762cf",
+                            format = "512"))
 })
